@@ -1,6 +1,7 @@
 import collections
 import inspect
 from abc import ABC
+from types import MethodType
 from typing import List, Callable, Iterable, Set, Dict, Type, Any, Union, Optional
 
 from mcdreforged.command.builder import command_builder_util as utils
@@ -149,13 +150,12 @@ class ArgumentNode:
 		sig = inspect.signature(callback)
 		spec_args = inspect.getfullargspec(callback).args
 		spec_args_len = len(spec_args)
+		if isinstance(callback, MethodType):  # class method, remove the 1st param
+			spec_args_len -= 1
 		try:
 			sig.bind(*args[:spec_args_len])  # test if using full arg length is ok
 		except TypeError:
-			if len(spec_args) > 0 and spec_args[0] == 'self':  # hacky fix for class method
-				spec_args_len -= 1
-			else:
-				raise
+			raise
 		return callback(*args[:spec_args_len])
 
 	def __handle_error(self, source, error: CommandError, context: dict, error_handlers: _ERROR_HANDLER_TYPE):
@@ -201,31 +201,34 @@ class ArgumentNode:
 				# Redirecting
 				node = self if self.redirect_node is None else self.redirect_node
 
+				argument_unknown = False
 				# No child at all
 				if not node.has_children():
-					self.__raise_error(source, UnknownArgument(command[:success_read], command), context)
+					argument_unknown = True
+				else:
+					# Pass the remaining command string to the children
+					try:
+						# Check literal children first
+						next_literal = utils.get_element(trimmed_remaining)
+						for child_literal in node.children_literal.get(next_literal, []):
+							try:
+								child_literal._execute(source, command, trimmed_remaining, context)
+								break
+							except LiteralNotMatch:
+								# it's ok for a direct literal node to fail
+								pass
+						else:  # All literal children fails
+							for child in node.children:
+								child._execute(source, command, trimmed_remaining, context)
+								break
+							else:  # No argument child
+								argument_unknown = True
+					except CommandError as error:
+						self.__handle_error(source, error, context, self.child_error_handlers)
+						raise error from None
 
-				# Pass the remaining command string to the children
-				try:
-					# Check literal children first
-					next_literal = utils.get_element(trimmed_remaining)
-					for child_literal in node.children_literal.get(next_literal, []):
-						try:
-							child_literal._execute(source, command, trimmed_remaining, context)
-							break
-						except LiteralNotMatch:
-							# it's ok for a direct literal node to fail
-							pass
-					else:  # All literal children fails
-						# No argument child
-						if len(node.children) == 0:
-							self.__raise_error(source, UnknownArgument(command[:success_read], command), context)
-						for child in node.children:
-							child._execute(source, command, trimmed_remaining, context)
-							break
-				except CommandError as error:
-					self.__handle_error(source, error, context, self.child_error_handlers)
-					raise error from None
+				if argument_unknown:
+					self.__raise_error(source, UnknownArgument(command[:success_read], command), context)
 
 
 class ExecutableNode(ArgumentNode, ABC):
