@@ -428,10 +428,9 @@ class MCDReforgedServer:
 		self.reactor_manager.put_info(parsed_result)
 
 	def __on_mcdr_start(self):
-		self.task_executor.start()
 		self.watch_dog.start()
-		self.load_plugins()
-		self.task_executor.wait_till_finish_all_task()
+		self.task_executor.start()
+		self.task_executor.execute_on_thread(self.load_plugins, wait=True)
 		self.plugin_manager.dispatch_event(MCDRPluginEvents.MCDR_START, ())
 		if not self.config['disable_console_thread']:
 			self.console_handler.start()
