@@ -321,6 +321,9 @@ class PluginManager:
 	#     3. Call on_unload for unloaded plugins
 
 	def __post_plugin_process(self, load_result=None, unload_result=None, reload_result=None):
+		"""
+		When returns, all events / operations are finished processing
+		"""
 		if load_result is None:
 			load_result = SingleOperationResult()
 		if unload_result is None:
@@ -338,12 +341,6 @@ class PluginManager:
 		# reload_result		READY				UNLOADING
 		# dep_chk_result	LOADED / READY		UNLOADING
 
-		# Stuffs execution order in self.mcdr_server.task_executor
-		# 1. PLUGIN_LOADED event listeners callbacks
-		# 2. self.__update_registry (watchdog disabled)
-		# 3. PLUGIN_LOADED, PLUGIN_REMOVED event listeners callbacks
-		# This method will wait until step 2 finishes before quiting
-
 		self.registry_storage.clear()  # in case plugin invokes dispatch_event during on_load. dont let them trigger listeners
 
 		for plugin in load_result.success_list + reload_result.success_list:
@@ -356,8 +353,6 @@ class PluginManager:
 				if isinstance(plugin, RegularPlugin):
 					plugin.receive_event(MCDRPluginEvents.PLUGIN_LOADED, (plugin.old_module_instance,))
 
-		self.mcdr_server.task_executor.add_regular_task(self.__update_registry)
-
 		for plugin in unload_result.success_list + unload_result.failed_list + reload_result.failed_list + dependency_check_result.failed_list:
 			plugin.assert_state({PluginState.UNLOADING})
 			# plugins might just be newly loaded but failed on dependency check, dont dispatch event to them
@@ -370,18 +365,18 @@ class PluginManager:
 		for plugin in self.get_regular_plugins():
 			plugin.assert_state({PluginState.READY})
 
+		self.__update_registry()
 		self.__sort_plugins_by_id()
 
 	def __sort_plugins_by_id(self):
 		self.plugins = dict(sorted(self.plugins.items(), key=lambda item: item[0]))
 
 	def __update_registry(self):
-		with self.mcdr_server.watch_dog.pausing():
-			self.registry_storage.clear()
-			for plugin in self.get_all_plugins():
-				self.registry_storage.collect(plugin.plugin_registry)
-			self.registry_storage.arrange()
-			self.mcdr_server.on_plugin_registry_changed()
+		self.registry_storage.clear()
+		for plugin in self.get_all_plugins():
+			self.registry_storage.collect(plugin.plugin_registry)
+		self.registry_storage.arrange()
+		self.mcdr_server.on_plugin_registry_changed()
 
 	def __refresh_plugins(self, reload_filter: Callable[[RegularPlugin], bool]):
 		unload_result = self.__collect_and_remove_plugins(lambda plugin: not plugin.file_exists())
@@ -446,9 +441,18 @@ class PluginManager:
 		"""
 		self.logger.debug('Dispatching {} with args ({})'.format(event, ', '.join([type(arg).__name__ for arg in args])), option=DebugOption.PLUGIN)
 		for listener in self.registry_storage.event_listeners.get(event.id, []):
-			self.__trigger_listener(listener, args)
+			self.trigger_listener(listener, args)
 
-	def __trigger_listener(self, listener: EventListener, args: Tuple[Any, ...]):
+	def dispatch_event(self, event: MCDREvent, args: Tuple[Any, ...], *, on_executor_thread=True, wait=False):
+		"""
+		Event dispatching interface
+		"""
+		if on_executor_thread:
+			self.mcdr_server.task_executor.execute_on_thread(lambda: self.__dispatch_event(event, args), wait=wait)
+		else:
+			self.__dispatch_event(event, args)
+
+	def trigger_listener(self, listener: EventListener, args: Tuple[Any, ...]):
 		"""
 		Event listener triggering implementation
 		The server_interface parameter will be automatically added as the 1st parameter
@@ -458,23 +462,3 @@ class PluginManager:
 				listener.execute(self.mcdr_server.server_interface, *args)
 			except:
 				self.logger.exception('Error invoking listener {}'.format(listener))
-
-	def dispatch_event(self, event: MCDREvent, args: Tuple[Any, ...], *, run_async=True, wait=False):
-		"""
-		Event dispatching interface. Event will be added into the task queue of the task executor thread
-		"""
-		if run_async:
-			self.mcdr_server.task_executor.add_regular_task(lambda: self.__dispatch_event(event, args), wait=wait)
-		else:
-			self.__dispatch_event(event, args)
-
-	def trigger_listener(self, listener: EventListener, args: Tuple[Any, ...], *, run_async=True, wait=False):
-		"""
-		Listener triggering interface. Event will be added into the task queue of the task executor thread
-		Should only be used in specific plugin listener triggering
-		"""
-		# self.thread_pool.add_task(lambda: listener.execute(*args), listener.plugin)
-		if run_async:
-			self.mcdr_server.task_executor.add_regular_task(lambda: self.__trigger_listener(listener, args), wait=wait)
-		else:
-			self.__trigger_listener(listener, args)
